@@ -196,12 +196,12 @@ def run_projects():
 # 这个脚本
 xserver_start_projects_script = """#!/usr/bin/python
 ### BEGIN INIT INFO
-# Provides: Hepochen
-# Required-Start:     $syslog $remote_fs
-# Required-Stop:      $syslog $remote_fs
-# Default-start: 5
-# Default-Stop: 6
-# Short-Description: auto start xserver containers
+# Provides:     Hepochen
+# Required-Start:    $all
+# Required-Stop:
+# Default-Start:     5
+# Default-Stop:
+# Short-Description:      auto start xserver containers
 ### END INIT INFO
 
 import sys,time
@@ -213,24 +213,31 @@ if __name__ == '__main__':
     if args and args[0] == 'status':
         print_docker_status()
     else:
-        time.sleep(3)
+        #time.sleep(1)
         run_projects()
     try:
         with open("/var/log/xserver_started.log", "a") as f:
-            f.write("%s: %s\n\n" % (time.time(), " ".join(sys.argv)))
+            f.write("%s: %s   " % (time.time(), " ".join(sys.argv)))
     except:
         pass
 """
 
 
+
 # ls /etc/rc*.d/
-# update-rc.d -f started remove && rm /etc/rc95.d/*started
+# update-rc.d -f started remove
 # xserver install_started
-# update-rc.d started defaults 95
+# update-rc.d started defaults 80 80
+# 内核 -> /etc/inittab -> /etc/ rc.sysinit (/etc/rc.d/rc.sysinit) -> /etc/rc[?].d (/etc/rc.d/rc[?].d) -> /etc/rc.local(/etc/rc.d/rc.local)
+# /usr/bin/python
+# /etc/rc.local
+# systemctl status started
+# systemctl enable started
+
 def install_xserver_started():
     script_filepath = '/etc/init.d/started'
     write_file(script_filepath, xserver_start_projects_script)
     run_commands('chmod +x %s' % script_filepath)
 
     run_commands('export LC_ALL="en_US.UTF-8"')
-    run_commands('update-rc.d started defaults 95') # 启动各项目容器的脚本
\ No newline at end of file
+    run_commands('update-rc.d started defaults 80 80') # 启动各项目容器的脚本
\ No newline at end of file
